@@ -2,6 +2,7 @@ import logging
 
 from wbtools.db.expression import WBExpressionDBManager
 from wbtools.db.generic import WBGenericDBManager
+from wbtools.db.paper import WBPaperDBManager
 from wbtools.db.person import WBPersonDBManager
 
 logger = logging.getLogger(__name__)
@@ -12,5 +13,5 @@ class WBDBManager(object):
     def __init__(self, dbname, user, password, host):
         self.generic = WBGenericDBManager(dbname, user, password, host)
         self.expression = WBExpressionDBManager(dbname, user, password, host)
-        self.paper = WBExpressionDBManager(dbname, user, password, host)
+        self.paper = WBPaperDBManager(dbname, user, password, host)
         self.person = WBPersonDBManager(dbname, user, password, host)
